searchData={"items":[{"type":"module","title":"Testcontainers","doc":"The main entry point into Testcontainers.\n\nThis is a GenServer that needs to be started before anything can happen.","ref":"Testcontainers.html"},{"type":"function","title":"Testcontainers.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Testcontainers.html#child_spec/1"},{"type":"function","title":"Testcontainers.start_container/1","doc":"Starts a new container based on the provided configuration, applying any specified wait strategies.\n\nThis function performs several steps:\n1. Pulls the necessary Docker image.\n2. Creates and starts a container with the specified configuration.\n3. Registers the container with a reaper process for automatic cleanup, ensuring it is stopped and removed when the current process exits or in case of unforeseen failures.","ref":"Testcontainers.html#start_container/1"},{"type":"function","title":"Parameters - Testcontainers.start_container/1","doc":"- `config`: A `%Container{}` struct containing the configuration settings for the container, such as the image to use, environment variables, bound ports, and volume bindings.","ref":"Testcontainers.html#start_container/1-parameters"},{"type":"function","title":"Examples - Testcontainers.start_container/1","doc":"iex> config = Testcontainers.MySqlContainer.new()\n    iex> {:ok, container} = Testcontainers.start_container(config)","ref":"Testcontainers.html#start_container/1-examples"},{"type":"function","title":"Returns - Testcontainers.start_container/1","doc":"- `{:ok, container}` if the container is successfully created, started, and passes all wait strategies.\n- An error tuple, such as `{:error, reason}`, if there is a failure at any step in the process.","ref":"Testcontainers.html#start_container/1-returns"},{"type":"function","title":"Notes - Testcontainers.start_container/1","doc":"- The container is automatically registered with a reaper process, ensuring it is stopped and removed when the current process exits, or in the case of unforeseen failures.\n- It's important to specify appropriate wait strategies to ensure the container is fully ready for interaction, especially for containers that may take some time to start up services internally.","ref":"Testcontainers.html#start_container/1-notes"},{"type":"function","title":"Testcontainers.start_link/1","doc":"","ref":"Testcontainers.html#start_link/1"},{"type":"function","title":"Testcontainers.stop_container/1","doc":"Stops a running container.\n\nThis sends a stop command to the specified container. The Docker daemon terminates the container process gracefully.","ref":"Testcontainers.html#stop_container/1"},{"type":"function","title":"Parameters - Testcontainers.stop_container/1","doc":"- `container_id`: The ID of the container to stop, as a string.","ref":"Testcontainers.html#stop_container/1-parameters"},{"type":"function","title":"Returns - Testcontainers.stop_container/1","doc":"- `:ok` if the container stops successfully.\n- `{:error, reason}` on failure.","ref":"Testcontainers.html#stop_container/1-returns"},{"type":"function","title":"Examples - Testcontainers.stop_container/1","doc":":ok = Testcontainers.Connection.stop_container(\"my_container_id\")","ref":"Testcontainers.html#stop_container/1-examples"},{"type":"module","title":"Testcontainers.CephContainer","doc":"Provides functionality for creating and managing Ceph container configurations.\n\nThis module provides functions for creating and manipulating configurations for Ceph containers.\nIt allows the setting of specific parameters like image, access keys, secret keys,\nand other parameters related to the Ceph container.","ref":"Testcontainers.CephContainer.html"},{"type":"function","title":"Testcontainers.CephContainer.connection_url/1","doc":"Generates the connection URL for accessing the Ceph service running within the container.\n\nThis URL is based on the standard localhost IP and the mapped port for the container.","ref":"Testcontainers.CephContainer.html#connection_url/1"},{"type":"function","title":"Parameters - Testcontainers.CephContainer.connection_url/1","doc":"- `container`: The active Ceph container instance.","ref":"Testcontainers.CephContainer.html#connection_url/1-parameters"},{"type":"function","title":"Examples - Testcontainers.CephContainer.connection_url/1","doc":"iex> CephContainer.connection_url(container)\n    \"http://localhost:32768\" # This value will be different depending on the mapped port.","ref":"Testcontainers.CephContainer.html#connection_url/1-examples"},{"type":"function","title":"Testcontainers.CephContainer.default_image/0","doc":"Retrieves the default Docker image used for the Ceph container.","ref":"Testcontainers.CephContainer.html#default_image/0"},{"type":"function","title":"Examples - Testcontainers.CephContainer.default_image/0","doc":"iex> CephContainer.default_image()\n    \"quay.io/ceph/demo\"","ref":"Testcontainers.CephContainer.html#default_image/0-examples"},{"type":"function","title":"Testcontainers.CephContainer.new/0","doc":"Creates a new `CephContainer` struct with default attributes.","ref":"Testcontainers.CephContainer.html#new/0"},{"type":"function","title":"Testcontainers.CephContainer.port/1","doc":"Retrieves the port mapped by the Docker host for the Ceph container.","ref":"Testcontainers.CephContainer.html#port/1"},{"type":"function","title":"Parameters - Testcontainers.CephContainer.port/1","doc":"- `container`: The active Ceph container instance.","ref":"Testcontainers.CephContainer.html#port/1-parameters"},{"type":"function","title":"Examples - Testcontainers.CephContainer.port/1","doc":"iex> CephContainer.port(container)\n    32768 # This value will be different depending on the mapped port.","ref":"Testcontainers.CephContainer.html#port/1-examples"},{"type":"function","title":"Testcontainers.CephContainer.with_access_key/2","doc":"Sets the `access_key` used for authentication with the Ceph container.","ref":"Testcontainers.CephContainer.html#with_access_key/2"},{"type":"function","title":"Examples - Testcontainers.CephContainer.with_access_key/2","doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_access_key(config, \"new_access_key\")\n    iex> new_config.access_key\n    \"new_access_key\"","ref":"Testcontainers.CephContainer.html#with_access_key/2-examples"},{"type":"function","title":"Testcontainers.CephContainer.with_bucket/2","doc":"Sets the `bucket` that is automatically in the Ceph container.","ref":"Testcontainers.CephContainer.html#with_bucket/2"},{"type":"function","title":"Examples - Testcontainers.CephContainer.with_bucket/2","doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_bucket(config, \"test_bucket\")\n    iex> new_config.bucket\n    \"test_bucket\"","ref":"Testcontainers.CephContainer.html#with_bucket/2-examples"},{"type":"function","title":"Testcontainers.CephContainer.with_image/2","doc":"Sets the `image` of the Ceph container configuration.","ref":"Testcontainers.CephContainer.html#with_image/2"},{"type":"function","title":"Examples - Testcontainers.CephContainer.with_image/2","doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_image(config, \"quay.io/ceph/alternative\")\n    iex> new_config.image\n    \"quay.io/ceph/alternative\"","ref":"Testcontainers.CephContainer.html#with_image/2-examples"},{"type":"function","title":"Testcontainers.CephContainer.with_port/2","doc":"Sets the port on which the Ceph container will be exposed.","ref":"Testcontainers.CephContainer.html#with_port/2"},{"type":"function","title":"Parameters - Testcontainers.CephContainer.with_port/2","doc":"- `config`: The current Ceph container configuration.\n- `port`: The target port number.","ref":"Testcontainers.CephContainer.html#with_port/2-parameters"},{"type":"function","title":"Examples - Testcontainers.CephContainer.with_port/2","doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_port(config, 8081)\n    iex> new_config.port\n    8081","ref":"Testcontainers.CephContainer.html#with_port/2-examples"},{"type":"function","title":"Testcontainers.CephContainer.with_secret_key/2","doc":"Sets the `secret_key` used for authentication with the Ceph container.","ref":"Testcontainers.CephContainer.html#with_secret_key/2"},{"type":"function","title":"Examples - Testcontainers.CephContainer.with_secret_key/2","doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_secret_key(config, \"new_secret_key\")\n    iex> new_config.secret_key\n    \"new_secret_key\"","ref":"Testcontainers.CephContainer.html#with_secret_key/2-examples"},{"type":"function","title":"Testcontainers.CephContainer.with_wait_timeout/2","doc":"Sets the maximum time (in milliseconds) the system will wait for the Ceph container to be ready before timing out.","ref":"Testcontainers.CephContainer.html#with_wait_timeout/2"},{"type":"function","title":"Parameters - Testcontainers.CephContainer.with_wait_timeout/2","doc":"- `config`: The current Ceph container configuration.\n- `wait_timeout`: The time to wait in milliseconds.","ref":"Testcontainers.CephContainer.html#with_wait_timeout/2-parameters"},{"type":"function","title":"Examples - Testcontainers.CephContainer.with_wait_timeout/2","doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_wait_timeout(config, 400_000)\n    iex> new_config.wait_timeout\n    400_000","ref":"Testcontainers.CephContainer.html#with_wait_timeout/2-examples"},{"type":"module","title":"Testcontainers.CommandWaitStrategy","doc":"Considers a container ready as soon as a command runs successfully inside it.","ref":"Testcontainers.CommandWaitStrategy.html"},{"type":"function","title":"Testcontainers.CommandWaitStrategy.new/3","doc":"Creates a new CommandWaitStrategy.\nThis strategy waits until the given command executes successfully inside the container.","ref":"Testcontainers.CommandWaitStrategy.html#new/3"},{"type":"module","title":"Testcontainers.Container","doc":"A struct with builder functions for creating a definition of a container.","ref":"Testcontainers.Container.html"},{"type":"function","title":"Testcontainers.Container.mapped_port/2","doc":"Gets the host port on the container for the given exposed port.","ref":"Testcontainers.Container.html#mapped_port/2"},{"type":"function","title":"Testcontainers.Container.new/2","doc":"A constructor function to make it easier to construct a container","ref":"Testcontainers.Container.html#new/2"},{"type":"function","title":"Testcontainers.Container.with_bind_mount/4","doc":"Sets a file or the directory on the _host machine_ to be mounted into a _container_.","ref":"Testcontainers.Container.html#with_bind_mount/4"},{"type":"function","title":"Testcontainers.Container.with_environment/3","doc":"Sets an _environment variable_ to the _container_.","ref":"Testcontainers.Container.html#with_environment/3"},{"type":"function","title":"Testcontainers.Container.with_exposed_port/2","doc":"Adds a _port_ to be exposed on the _container_.","ref":"Testcontainers.Container.html#with_exposed_port/2"},{"type":"function","title":"Testcontainers.Container.with_exposed_ports/2","doc":"Adds multiple _ports_ to be exposed on the _container_.","ref":"Testcontainers.Container.html#with_exposed_ports/2"},{"type":"function","title":"Testcontainers.Container.with_fixed_port/3","doc":"","ref":"Testcontainers.Container.html#with_fixed_port/3"},{"type":"function","title":"Testcontainers.Container.with_label/3","doc":"Sets a label to apply to the container object in docker.","ref":"Testcontainers.Container.html#with_label/3"},{"type":"function","title":"Testcontainers.Container.with_waiting_strategies/2","doc":"Sets multiple _waiting strategies_ for the _container_.","ref":"Testcontainers.Container.html#with_waiting_strategies/2"},{"type":"function","title":"Testcontainers.Container.with_waiting_strategy/2","doc":"Sets a _waiting strategy_ for the _container_.","ref":"Testcontainers.Container.html#with_waiting_strategy/2"},{"type":"module","title":"Testcontainers.Container.CephContainer","doc":"Deprecated. Use `Testcontainers.CephContainer` instead.\n\nThis module is kept for backward compatibility and will be removed in future releases.","ref":"Testcontainers.Container.CephContainer.html"},{"type":"function","title":"Testcontainers.Container.CephContainer.connection_url/1","doc":"","ref":"Testcontainers.Container.CephContainer.html#connection_url/1"},{"type":"function","title":"Testcontainers.Container.CephContainer.new/0","doc":"","ref":"Testcontainers.Container.CephContainer.html#new/0"},{"type":"function","title":"Testcontainers.Container.CephContainer.port/1","doc":"","ref":"Testcontainers.Container.CephContainer.html#port/1"},{"type":"function","title":"Testcontainers.Container.CephContainer.with_access_key/2","doc":"","ref":"Testcontainers.Container.CephContainer.html#with_access_key/2"},{"type":"function","title":"Testcontainers.Container.CephContainer.with_bucket/2","doc":"","ref":"Testcontainers.Container.CephContainer.html#with_bucket/2"},{"type":"function","title":"Testcontainers.Container.CephContainer.with_image/2","doc":"","ref":"Testcontainers.Container.CephContainer.html#with_image/2"},{"type":"function","title":"Testcontainers.Container.CephContainer.with_port/2","doc":"","ref":"Testcontainers.Container.CephContainer.html#with_port/2"},{"type":"function","title":"Testcontainers.Container.CephContainer.with_secret_key/2","doc":"","ref":"Testcontainers.Container.CephContainer.html#with_secret_key/2"},{"type":"function","title":"Testcontainers.Container.CephContainer.with_wait_timeout/2","doc":"","ref":"Testcontainers.Container.CephContainer.html#with_wait_timeout/2"},{"type":"module","title":"Testcontainers.Container.MySqlContainer","doc":"Deprecated. Use `Testcontainers.MySqlContainer` instead.\n\nThis module is kept for backward compatibility and will be removed in future releases.","ref":"Testcontainers.Container.MySqlContainer.html"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.connection_parameters/1","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#connection_parameters/1"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.default_image_with_tag/0","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#default_image_with_tag/0"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.default_port/0","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#default_port/0"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.new/0","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#new/0"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.port/1","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#port/1"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.with_database/2","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_database/2"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.with_image/2","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_image/2"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.with_password/2","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_password/2"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.with_port/2","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_port/2"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.with_user/2","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_user/2"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.with_wait_timeout/2","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_wait_timeout/2"},{"type":"module","title":"Testcontainers.Container.PostgresContainer","doc":"Deprecated. Use `Testcontainers.PostgresContainer` instead.\n\nThis module is kept for backward compatibility and will be removed in future releases.","ref":"Testcontainers.Container.PostgresContainer.html"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.connection_parameters/1","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#connection_parameters/1"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.default_image_with_tag/0","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#default_image_with_tag/0"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.default_port/0","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#default_port/0"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.new/0","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#new/0"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.port/1","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#port/1"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.with_database/2","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_database/2"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.with_image/2","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_image/2"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.with_password/2","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_password/2"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.with_port/2","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_port/2"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.with_user/2","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_user/2"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.with_wait_timeout/2","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_wait_timeout/2"},{"type":"module","title":"Testcontainers.Container.RedisContainer","doc":"Deprecated. Use `Testcontainers.RedisContainer` instead.\n\nThis module is kept for backward compatibility and will be removed in future releases.","ref":"Testcontainers.Container.RedisContainer.html"},{"type":"function","title":"Testcontainers.Container.RedisContainer.connection_url/1","doc":"","ref":"Testcontainers.Container.RedisContainer.html#connection_url/1"},{"type":"function","title":"Testcontainers.Container.RedisContainer.new/0","doc":"","ref":"Testcontainers.Container.RedisContainer.html#new/0"},{"type":"function","title":"Testcontainers.Container.RedisContainer.port/1","doc":"","ref":"Testcontainers.Container.RedisContainer.html#port/1"},{"type":"function","title":"Testcontainers.Container.RedisContainer.with_image/2","doc":"","ref":"Testcontainers.Container.RedisContainer.html#with_image/2"},{"type":"function","title":"Testcontainers.Container.RedisContainer.with_port/2","doc":"","ref":"Testcontainers.Container.RedisContainer.html#with_port/2"},{"type":"function","title":"Testcontainers.Container.RedisContainer.with_wait_timeout/2","doc":"","ref":"Testcontainers.Container.RedisContainer.html#with_wait_timeout/2"},{"type":"module","title":"Testcontainers.Container.SeleniumContainer","doc":"Deprecated. Use `Testcontainers.SeleniumContainer` instead.\n\nThis module is kept for backward compatibility and will be removed in future releases.","ref":"Testcontainers.Container.SeleniumContainer.html"},{"type":"function","title":"Testcontainers.Container.SeleniumContainer.new/0","doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#new/0"},{"type":"function","title":"Testcontainers.Container.SeleniumContainer.with_image/2","doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#with_image/2"},{"type":"function","title":"Testcontainers.Container.SeleniumContainer.with_port1/2","doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#with_port1/2"},{"type":"function","title":"Testcontainers.Container.SeleniumContainer.with_port2/2","doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#with_port2/2"},{"type":"function","title":"Testcontainers.Container.SeleniumContainer.with_wait_timeout/2","doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#with_wait_timeout/2"},{"type":"protocol","title":"Testcontainers.ContainerBuilder","doc":"All types of predefined containers must implement this protocol.","ref":"Testcontainers.ContainerBuilder.html"},{"type":"function","title":"Testcontainers.ContainerBuilder.build/1","doc":"","ref":"Testcontainers.ContainerBuilder.html#build/1"},{"type":"type","title":"Testcontainers.ContainerBuilder.t/0","doc":"All the types that implement this protocol.","ref":"Testcontainers.ContainerBuilder.html#t:t/0"},{"type":"behaviour","title":"Testcontainers.DatabaseBehaviour","doc":"A behaviour implemented by database containers used by `Testcontainers.Ecto`","ref":"Testcontainers.DatabaseBehaviour.html"},{"type":"callback","title":"Testcontainers.DatabaseBehaviour.new/0","doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:new/0"},{"type":"callback","title":"Testcontainers.DatabaseBehaviour.with_database/2","doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_database/2"},{"type":"callback","title":"Testcontainers.DatabaseBehaviour.with_image/2","doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_image/2"},{"type":"callback","title":"Testcontainers.DatabaseBehaviour.with_password/2","doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_password/2"},{"type":"callback","title":"Testcontainers.DatabaseBehaviour.with_port/2","doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_port/2"},{"type":"callback","title":"Testcontainers.DatabaseBehaviour.with_user/2","doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_user/2"},{"type":"type","title":"Testcontainers.DatabaseBehaviour.t/0","doc":"","ref":"Testcontainers.DatabaseBehaviour.html#t:t/0"},{"type":"module","title":"Testcontainers.Docker.Api","doc":"Internal docker api. Only for direct use by `Testcontainers`","ref":"Testcontainers.Docker.Api.html"},{"type":"function","title":"Testcontainers.Docker.Api.create_container/2","doc":"","ref":"Testcontainers.Docker.Api.html#create_container/2"},{"type":"function","title":"Testcontainers.Docker.Api.get_container/2","doc":"","ref":"Testcontainers.Docker.Api.html#get_container/2"},{"type":"function","title":"Testcontainers.Docker.Api.inspect_exec/2","doc":"","ref":"Testcontainers.Docker.Api.html#inspect_exec/2"},{"type":"function","title":"Testcontainers.Docker.Api.pull_image/2","doc":"","ref":"Testcontainers.Docker.Api.html#pull_image/2"},{"type":"function","title":"Testcontainers.Docker.Api.start_container/2","doc":"","ref":"Testcontainers.Docker.Api.html#start_container/2"},{"type":"function","title":"Testcontainers.Docker.Api.start_exec/3","doc":"","ref":"Testcontainers.Docker.Api.html#start_exec/3"},{"type":"function","title":"Testcontainers.Docker.Api.stdout_logs/2","doc":"","ref":"Testcontainers.Docker.Api.html#stdout_logs/2"},{"type":"function","title":"Testcontainers.Docker.Api.stop_container/2","doc":"","ref":"Testcontainers.Docker.Api.html#stop_container/2"},{"type":"module","title":"Testcontainers.Ecto","doc":"Facilitates the creation of a Postgres or MySql container for testing with Ecto.\n\nThis module simplifies the process of launching a real Postgres or MySql database instance within a Docker container for testing purposes. It leverages the `Testcontainers` library to instantiate a Postgres or MySql container with the desired configuration, providing an isolated database environment for each test session.","ref":"Testcontainers.Ecto.html"},{"type":"function","title":"Testcontainers.Ecto.mysql_container/1","doc":"Initiates a new Mysql instance, executes migrations, and prepares a suitable database environment, specifically tailored for testing scenarios.","ref":"Testcontainers.Ecto.html#mysql_container/1"},{"type":"function","title":"Parameters - Testcontainers.Ecto.mysql_container/1","doc":"- `options`: Configurations for the Mysql container, provided as a keyword list. The only required option is `:app`. Other options include:\n  - `:app` - The current application's atom, necessary for building paths and other application-specific logic. This is a required parameter.\n  - `:repo` (optional) - The Ecto repository module for database interaction. If not provided, it is inferred from the `:app` option using the default naming convention (e.g., `MyApp.Repo`).\n  - `:image` (optional) - Specifies the Docker image for the Mysql container. This must be a legitimate Mysql image, with the image name beginning with \"mysql\". If omitted, the default is \"mysql:8\".\n  - `:user` (optional) - Sets the username for the Mysql instance (defaults to \"test\").\n  - `:password` (optional) - Determines the password for the Mysql user (defaults to \"test\").\n  - `:database` (optional) - Specifies the name of the database to be created within the Mysql instance. If not provided, the default behavior is to create a database with the name derived from the application's atom, appended with \"_test\".\n  - `:migrations_path` (optional) - Indicates the path to the migrations folder (defaults to \"priv/repo/migrations\").","ref":"Testcontainers.Ecto.html#mysql_container/1-parameters"},{"type":"function","title":"Database Lifecycle in Testing - Testcontainers.Ecto.mysql_container/1","doc":"It's important to note that the Mysql database initiated by this function will remain operational for the duration of the test process and is not explicitly shut down by the function. The database and its corresponding data are ephemeral, lasting only for the scope of the test session.\n\nAfter the tests conclude, Testcontainers will clean up by removing the database container, ensuring no residual data persists. This approach helps maintain a clean testing environment and prevents any unintended side effects on subsequent tests due to data leftovers.\n\nUsers should not rely on any manual teardown or cleanup for the database, as Testcontainers handles this aspect automatically, providing isolated, repeatable test runs.","ref":"Testcontainers.Ecto.html#mysql_container/1-database-lifecycle-in-testing"},{"type":"function","title":"Examples - Testcontainers.Ecto.mysql_container/1","doc":"# First, you must change the Ecto adapter from Postgres to MyXQL\n\n    defmodule MyApp.Repo do\n      use Ecto.Repo,\n        otp_app: :my_app,\n        adapter: Ecto.Adapters.MyXQL # <- should look like this\n    end\n\n    # Then, in your application.ex file in your Phoenix project:\n\n    import Testcontainers.Ecto\n\n    @impl true\n    def start(_type, _args) do\n      mysql_container(\n        app: :my_app,\n        user: \"postgres\", # consider changing this to something else here and in config/test.exs\n        password: \"postgres\" # consider changing this to something else here and in config/test.exs\n      )\n\n      # .. other setup code\n    end\n\n    # Lastly, in mix.exs, modify the aliases to remove default Ecto setup tasks from the test alias,\n    # as they might interfere with the container-based database setup:\n\n    def aliases do\n      [\n        # ... other aliases\n\n        # Ensure the following line is NOT present, as it would conflict with the container setup:\n        # test: [\"ecto.create --quiet\", \"ecto.migrate --quiet\", \"test\"],\n      ]\n    end\n\n    # in your config/test.exs, if you want to keep appending the MIX_TEST_PARTITION env variable to the database name,\n    # you must set the database option in mysql_container function to the same value\n\n    config :my_app, MyApp.Repo,\n      username: \"postgres\", # <- consider changing this when using mysql\n      password: \"postgres\", # <- consider changing this when using mysql\n      hostname: \"localhost\",\n      database: \"my_app_test#{System.get_env(\"MIX_TEST_PARTITION\")}\", # set this also in mysql_container function database option, or remove the appending\n      pool: Ecto.Adapters.SQL.Sandbox,\n      pool_size: 10\n\n    # for example, to set the database name to the one above, in application.ex:\n\n    @impl true\n    def start(_type, _args) do\n      mysql_container(\n        app: :my_app,\n        user: \"postgres\", # <- consider changing this when using mysql\n        password: \"postgres\", # <- consider changing this when using mysql\n        database: \"my_app_test#{System.get_env(\"MIX_TEST_PARTITION\")}\"\n      )\n\n      # .. other setup code\n    end","ref":"Testcontainers.Ecto.html#mysql_container/1-examples"},{"type":"function","title":"Returns - Testcontainers.Ecto.mysql_container/1","doc":"- `:ok` if the container is initiated successfully.\n- `{:error, reason}` if there is a failure in initiating the container, with `reason` explaining the cause of the failure.","ref":"Testcontainers.Ecto.html#mysql_container/1-returns"},{"type":"function","title":"Errors - Testcontainers.Ecto.mysql_container/1","doc":"- Raises `ArgumentError` if the application is missing, not an atom, or not loaded.\n- Raises `ArgumentError` if the repo is defined and not an atom\n- Raises `ArgumentError` if the specified Docker image is not a valid MySql image.","ref":"Testcontainers.Ecto.html#mysql_container/1-errors"},{"type":"function","title":"Note - Testcontainers.Ecto.mysql_container/1","doc":"This utility is intended for testing environments requiring a genuine database instance. It is not suitable for production use. It mandates a valid Postgres Docker image to maintain consistent and reliable testing conditions.","ref":"Testcontainers.Ecto.html#mysql_container/1-note"},{"type":"function","title":"Testcontainers.Ecto.postgres_container/1","doc":"Initiates a new Postgres instance, executes migrations, and prepares a suitable database environment, specifically tailored for testing scenarios.","ref":"Testcontainers.Ecto.html#postgres_container/1"},{"type":"function","title":"Parameters - Testcontainers.Ecto.postgres_container/1","doc":"- `options`: Configurations for the Postgres container, provided as a keyword list. The only required option is `:app`. Other options include:\n  - `:app` - The current application's atom, necessary for building paths and other application-specific logic. This is a required parameter.\n  - `:repo` (optional) - The Ecto repository module for database interaction. If not provided, it is inferred from the `:app` option using the default naming convention (e.g., `MyApp.Repo`).\n  - `:image` (optional) - Specifies the Docker image for the Postgres container. This must be a legitimate Postgres image, with the image name beginning with \"postgres\". If omitted, the default is \"postgres:15\".\n  - `:user` (optional) - Sets the username for the Postgres instance (defaults to \"postgres\").\n  - `:password` (optional) - Determines the password for the Postgres user (defaults to \"postgres\").\n  - `:database` (optional) - Specifies the name of the database to be created within the Postgres instance. If not provided, the default behavior is to create a database with the name derived from the application's atom, appended with \"_test\".\n  - `:migrations_path` (optional) - Indicates the path to the migrations folder (defaults to \"priv/repo/migrations\").","ref":"Testcontainers.Ecto.html#postgres_container/1-parameters"},{"type":"function","title":"Database Lifecycle in Testing - Testcontainers.Ecto.postgres_container/1","doc":"It's important to note that the Postgres database initiated by this function will remain operational for the duration of the test process and is not explicitly shut down by the test. The database and its corresponding data are ephemeral, lasting only for the scope of the test session.\n\nAfter the tests conclude, Testcontainers will clean up by removing the database container, ensuring no residual data persists. This approach helps maintain a clean testing environment and prevents any unintended side effects on subsequent tests due to data leftovers.\n\nUsers should not rely on any manual teardown or cleanup for the database, as Testcontainers handles this aspect automatically, providing isolated, repeatable test runs.","ref":"Testcontainers.Ecto.html#postgres_container/1-database-lifecycle-in-testing"},{"type":"function","title":"Examples - Testcontainers.Ecto.postgres_container/1","doc":"# In your application.ex file in your Phoenix project:\n\n    import Testcontainers.Ecto\n\n    @impl true\n    def start(_type, _args) do\n      postgres_container(\n        app: :my_app,\n        user: \"postgres\",\n        password: \"postgres\"\n      )\n\n      # .. other setup code\n    end\n\n    # In mix.exs, modify the aliases to remove default Ecto setup tasks from the test alias,\n    # as they might interfere with the container-based database setup:\n\n    def aliases do\n      [\n        # ... other aliases\n\n        # Ensure the following line is NOT present, as it would conflict with the container setup:\n        # test: [\"ecto.create --quiet\", \"ecto.migrate --quiet\", \"test\"],\n      ]\n    end\n\n    # in your config/test.exs, if you want to keep appending the MIX_TEST_PARTITION env variable to the database name,\n    # you must set the database option in postgres_container function to the same value\n\n    config :my_app, MyApp.Repo,\n      username: \"postgres\",\n      password: \"postgres\",\n      hostname: \"localhost\",\n      database: \"my_app_test#{System.get_env(\"MIX_TEST_PARTITION\")}\", # set this also in postgres_container function database option, or remove the appending\n      pool: Ecto.Adapters.SQL.Sandbox,\n      pool_size: 10\n\n    # for example, to set the database name to the one above, in application.ex:\n\n    @impl true\n    def start(_type, _args) do\n      postgres_container(\n        app: :my_app,\n        user: \"postgres\",\n        password: \"postgres\",\n        database: \"my_app_test#{System.get_env(\"MIX_TEST_PARTITION\")}\"\n      )\n\n      # .. other setup code\n    end","ref":"Testcontainers.Ecto.html#postgres_container/1-examples"},{"type":"function","title":"Returns - Testcontainers.Ecto.postgres_container/1","doc":"- `:ok` if the container is initiated successfully.\n- `{:error, reason}` if there is a failure in initiating the container, with `reason` explaining the cause of the failure.","ref":"Testcontainers.Ecto.html#postgres_container/1-returns"},{"type":"function","title":"Errors - Testcontainers.Ecto.postgres_container/1","doc":"- Raises `ArgumentError` if the application is missing, not an atom, or not loaded.\n- Raises `ArgumentError` if the repo is defined and not an atom\n- Raises `ArgumentError` if the specified Docker image is not a valid Postgres image.","ref":"Testcontainers.Ecto.html#postgres_container/1-errors"},{"type":"function","title":"Note - Testcontainers.Ecto.postgres_container/1","doc":"This utility is intended for testing environments requiring a genuine database instance. It is not suitable for production use. It mandates a valid Postgres Docker image to maintain consistent and reliable testing conditions.","ref":"Testcontainers.Ecto.html#postgres_container/1-note"},{"type":"module","title":"Testcontainers.ExUnit","doc":"Convenient macros to run containers within ExUnit tests.","ref":"Testcontainers.ExUnit.html"},{"type":"macro","title":"Testcontainers.ExUnit.container/3","doc":"Creates and manages the lifecycle of a container within ExUnit tests.\n\nWhen the `:shared` option is set to `true`, the container is created once for all tests in the module. It initializes the container before any test is run and keeps it running across multiple tests. This is useful for scenarios where the cost of setting up and tearing down the container is high, or the tests are read-only and won't change the container's state.\n\nWhen the `:shared` option is omitted or set to `false`, a new container is created for each individual test, ensuring a clean state for each test case. The container is removed after each test finishes.","ref":"Testcontainers.ExUnit.html#container/3"},{"type":"macro","title":"Parameters - Testcontainers.ExUnit.container/3","doc":"* `name`: The key that should be used to reference the container in test cases.\n  * `config`: Configuration necessary for initializing the container.\n  * `options`: Optional keyword list. Supports the following options:\n    * `:shared` - If set to `true`, the container is shared across all tests in the module. If `false` or omitted, a new container is used for each test.","ref":"Testcontainers.ExUnit.html#container/3-parameters"},{"type":"macro","title":"Examples - Testcontainers.ExUnit.container/3","doc":"To create a new container for each test:\n\n    defmodule MyTest do\n      use ExUnit.Case\n\n      alias Testcontainers.Container\n\n      container :my_container, %Container{image: \"my_image\"}\n      # ...\n    end\n\nTo share a container across all tests in the module:\n\n    defmodule MySharedTest do\n      use ExUnit.Case\n\n      alias Testcontainers.Container\n\n      container :my_shared_container, %Container{image: \"my_shared_image\"}, shared: true\n      # ...\n    end","ref":"Testcontainers.ExUnit.html#container/3-examples"},{"type":"macro","title":"Notes - Testcontainers.ExUnit.container/3","doc":"* The macro sets up the necessary ExUnit callbacks to manage the container's lifecycle.\n  * It ensures the `Connection` and `Reaper` are started before initializing a container.\n  * In the case of shared containers, be mindful that tests can affect the container's state, potentially leading to interdependencies between tests.","ref":"Testcontainers.ExUnit.html#container/3-notes"},{"type":"module","title":"Testcontainers.LogWaitStrategy","doc":"Considers the container as ready as soon as a specific log message is detected in the container's log stream.","ref":"Testcontainers.LogWaitStrategy.html"},{"type":"function","title":"Testcontainers.LogWaitStrategy.new/3","doc":"Creates a new LogWaitStrategy.\nThis strategy waits until a specific log message, matching the provided regex, appears in the container's log.","ref":"Testcontainers.LogWaitStrategy.html#new/3"},{"type":"module","title":"Testcontainers.Logger","doc":"Defines an abstraction on top of Elixir.Logger","ref":"Testcontainers.Logger.html"},{"type":"function","title":"Testcontainers.Logger.log/1","doc":"","ref":"Testcontainers.Logger.html#log/1"},{"type":"module","title":"Testcontainers.MySqlContainer","doc":"Provides functionality for creating and managing MySQL container configurations.\n\nThis module includes helper methods for setting up a MySQL container with specific parameters such as image, user, password, database, and more.","ref":"Testcontainers.MySqlContainer.html"},{"type":"function","title":"Testcontainers.MySqlContainer.connection_parameters/1","doc":"Returns the connection parameters to connect to the database from the _host machine_.","ref":"Testcontainers.MySqlContainer.html#connection_parameters/1"},{"type":"function","title":"Testcontainers.MySqlContainer.default_image/0","doc":"Retrieves the default Docker image for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#default_image/0"},{"type":"function","title":"Testcontainers.MySqlContainer.default_image_with_tag/0","doc":"Retrieves the default Docker image including tag for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#default_image_with_tag/0"},{"type":"function","title":"Testcontainers.MySqlContainer.default_port/0","doc":"Retrieves the default exposed port for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#default_port/0"},{"type":"function","title":"Testcontainers.MySqlContainer.new/0","doc":"Creates a new `MySqlContainer` struct with default configurations.","ref":"Testcontainers.MySqlContainer.html#new/0"},{"type":"function","title":"Testcontainers.MySqlContainer.port/1","doc":"Returns the port on the _host machine_ where the MySql container is listening.","ref":"Testcontainers.MySqlContainer.html#port/1"},{"type":"function","title":"Testcontainers.MySqlContainer.with_database/2","doc":"Overrides the default database used for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#with_database/2"},{"type":"function","title":"Examples - Testcontainers.MySqlContainer.with_database/2","doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_database(config, \"another-database\")\n    iex> new_config.database\n    \"another-database\"","ref":"Testcontainers.MySqlContainer.html#with_database/2-examples"},{"type":"function","title":"Testcontainers.MySqlContainer.with_image/2","doc":"Overrides the default image used for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#with_image/2"},{"type":"function","title":"Examples - Testcontainers.MySqlContainer.with_image/2","doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_image(config, \"mysql:4\")\n    iex> new_config.image\n    \"mysql:4\"","ref":"Testcontainers.MySqlContainer.html#with_image/2-examples"},{"type":"function","title":"Testcontainers.MySqlContainer.with_password/2","doc":"Overrides the default password used for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#with_password/2"},{"type":"function","title":"Examples - Testcontainers.MySqlContainer.with_password/2","doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_password(config, \"another-password\")\n    iex> new_config.password\n    \"another-password\"","ref":"Testcontainers.MySqlContainer.html#with_password/2-examples"},{"type":"function","title":"Testcontainers.MySqlContainer.with_port/2","doc":"Overrides the default port used for the MySQL container.\n\nNote: this will not change what port the docker container is listening to internally.","ref":"Testcontainers.MySqlContainer.html#with_port/2"},{"type":"function","title":"Examples - Testcontainers.MySqlContainer.with_port/2","doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_port(config, 3307)\n    iex> new_config.port\n    3307","ref":"Testcontainers.MySqlContainer.html#with_port/2-examples"},{"type":"function","title":"Testcontainers.MySqlContainer.with_user/2","doc":"Overrides the default user used for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#with_user/2"},{"type":"function","title":"Examples - Testcontainers.MySqlContainer.with_user/2","doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_user(config, \"another-user\")\n    iex> new_config.user\n    \"another-user\"","ref":"Testcontainers.MySqlContainer.html#with_user/2-examples"},{"type":"function","title":"Testcontainers.MySqlContainer.with_wait_timeout/2","doc":"Overrides the default wait timeout used for the MySQL container.\n\nNote: this timeout will be used for each individual wait strategy.","ref":"Testcontainers.MySqlContainer.html#with_wait_timeout/2"},{"type":"function","title":"Examples - Testcontainers.MySqlContainer.with_wait_timeout/2","doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_wait_timeout(config, 8000)\n    iex> new_config.wait_timeout\n    8000","ref":"Testcontainers.MySqlContainer.html#with_wait_timeout/2-examples"},{"type":"module","title":"Testcontainers.PortWaitStrategy","doc":"Considers the container as ready when it successfully accepts connections on the specified port.","ref":"Testcontainers.PortWaitStrategy.html"},{"type":"function","title":"Testcontainers.PortWaitStrategy.new/4","doc":"Creates a new PortWaitStrategy to wait until a specified port is open and accepting connections.","ref":"Testcontainers.PortWaitStrategy.html#new/4"},{"type":"module","title":"Testcontainers.PostgresContainer","doc":"Provides functionality for creating and managing Postgres container configurations.\n\nThis module includes helper methods for setting up a Postgres container with specific parameters such as image, user, password, database, and more.","ref":"Testcontainers.PostgresContainer.html"},{"type":"function","title":"Testcontainers.PostgresContainer.connection_parameters/1","doc":"Returns the connection parameters to connect to the database from the _host machine_.","ref":"Testcontainers.PostgresContainer.html#connection_parameters/1"},{"type":"function","title":"Testcontainers.PostgresContainer.default_image/0","doc":"Retrieves the default Docker image for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#default_image/0"},{"type":"function","title":"Testcontainers.PostgresContainer.default_image_with_tag/0","doc":"Retrieves the default Docker image including tag for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#default_image_with_tag/0"},{"type":"function","title":"Testcontainers.PostgresContainer.default_port/0","doc":"Retrieves the default exposed port for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#default_port/0"},{"type":"function","title":"Testcontainers.PostgresContainer.new/0","doc":"Creates a new `PostgresContainer` struct with default configurations.","ref":"Testcontainers.PostgresContainer.html#new/0"},{"type":"function","title":"Testcontainers.PostgresContainer.port/1","doc":"Returns the port on the _host machine_ where the Postgres container is listening.","ref":"Testcontainers.PostgresContainer.html#port/1"},{"type":"function","title":"Testcontainers.PostgresContainer.with_database/2","doc":"Overrides the default database used for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#with_database/2"},{"type":"function","title":"Examples - Testcontainers.PostgresContainer.with_database/2","doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_database(config, \"another-database\")\n    iex> new_config.database\n    \"another-database\"","ref":"Testcontainers.PostgresContainer.html#with_database/2-examples"},{"type":"function","title":"Testcontainers.PostgresContainer.with_image/2","doc":"Overrides the default image used for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#with_image/2"},{"type":"function","title":"Examples - Testcontainers.PostgresContainer.with_image/2","doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_image(config, \"postgres:12\")\n    iex> new_config.image\n    \"postgres:12\"","ref":"Testcontainers.PostgresContainer.html#with_image/2-examples"},{"type":"function","title":"Testcontainers.PostgresContainer.with_password/2","doc":"Overrides the default password used for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#with_password/2"},{"type":"function","title":"Examples - Testcontainers.PostgresContainer.with_password/2","doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_password(config, \"another-password\")\n    iex> new_config.password\n    \"another-password\"","ref":"Testcontainers.PostgresContainer.html#with_password/2-examples"},{"type":"function","title":"Testcontainers.PostgresContainer.with_port/2","doc":"Overrides the default port used for the Postgres container.\n\nNote: this will not change what port the docker container is listening to internally.","ref":"Testcontainers.PostgresContainer.html#with_port/2"},{"type":"function","title":"Examples - Testcontainers.PostgresContainer.with_port/2","doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_port(config, 2345)\n    iex> new_config.port\n    2345","ref":"Testcontainers.PostgresContainer.html#with_port/2-examples"},{"type":"function","title":"Testcontainers.PostgresContainer.with_user/2","doc":"Overrides the default user used for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#with_user/2"},{"type":"function","title":"Examples - Testcontainers.PostgresContainer.with_user/2","doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_user(config, \"another-user\")\n    iex> new_config.user\n    \"another-user\"","ref":"Testcontainers.PostgresContainer.html#with_user/2-examples"},{"type":"function","title":"Testcontainers.PostgresContainer.with_wait_timeout/2","doc":"Overrides the default wait timeout used for the Postgres container.\n\nNote: this timeout will be used for each individual wait strategy.","ref":"Testcontainers.PostgresContainer.html#with_wait_timeout/2"},{"type":"function","title":"Examples - Testcontainers.PostgresContainer.with_wait_timeout/2","doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_wait_timeout(config, 8000)\n    iex> new_config.wait_timeout\n    8000","ref":"Testcontainers.PostgresContainer.html#with_wait_timeout/2-examples"},{"type":"module","title":"Testcontainers.RedisContainer","doc":"Provides functionality for creating and managing Redis container configurations.\n\nThis module includes helper methods for setting up a Redis container with specific parameters such as image and more.","ref":"Testcontainers.RedisContainer.html"},{"type":"function","title":"Testcontainers.RedisContainer.connection_url/1","doc":"Generates the connection URL for accessing the Redis service running within the container.\n\nThis URL is based on the standard localhost IP and the mapped port for the container.","ref":"Testcontainers.RedisContainer.html#connection_url/1"},{"type":"function","title":"Parameters - Testcontainers.RedisContainer.connection_url/1","doc":"- `container`: The active Redis container instance in the form of a %Container{} struct.","ref":"Testcontainers.RedisContainer.html#connection_url/1-parameters"},{"type":"function","title":"Examples - Testcontainers.RedisContainer.connection_url/1","doc":"iex> RedisContainer.connection_url(container)\n    \"http://localhost:32768\" # This value will be different depending on the mapped port.","ref":"Testcontainers.RedisContainer.html#connection_url/1-examples"},{"type":"function","title":"Testcontainers.RedisContainer.default_image/0","doc":"Retrieves the default Docker image for the Redis container.","ref":"Testcontainers.RedisContainer.html#default_image/0"},{"type":"function","title":"Testcontainers.RedisContainer.new/0","doc":"Creates a new `RedisContainer` struct with default configurations.","ref":"Testcontainers.RedisContainer.html#new/0"},{"type":"function","title":"Testcontainers.RedisContainer.port/1","doc":"Returns the port on the _host machine_ where the Redis container is listening.","ref":"Testcontainers.RedisContainer.html#port/1"},{"type":"function","title":"Testcontainers.RedisContainer.with_image/2","doc":"Overrides the default image used for the Redis container.","ref":"Testcontainers.RedisContainer.html#with_image/2"},{"type":"function","title":"Examples - Testcontainers.RedisContainer.with_image/2","doc":"iex> config = RedisContainer.new()\n    iex> new_config = RedisContainer.with_image(config, \"redis:xyz\")\n    iex> new_config.image\n    \"redis:xyz\"","ref":"Testcontainers.RedisContainer.html#with_image/2-examples"},{"type":"function","title":"Testcontainers.RedisContainer.with_port/2","doc":"Overrides the default port used for the Redis container.\n\nNote: this will not change what port the docker container is listening to internally.","ref":"Testcontainers.RedisContainer.html#with_port/2"},{"type":"function","title":"Examples - Testcontainers.RedisContainer.with_port/2","doc":"iex> config = RedisContainer.new()\n    iex> new_config = RedisContainer.with_port(config, 1111)\n    iex> new_config.port\n    1111","ref":"Testcontainers.RedisContainer.html#with_port/2-examples"},{"type":"function","title":"Testcontainers.RedisContainer.with_wait_timeout/2","doc":"Overrides the default wait timeout used for the Redis container.\n\nNote: this timeout will be used for each individual wait strategy.","ref":"Testcontainers.RedisContainer.html#with_wait_timeout/2"},{"type":"function","title":"Examples - Testcontainers.RedisContainer.with_wait_timeout/2","doc":"iex> config = RedisContainer.new()\n    iex> new_config = RedisContainer.with_wait_timeout(config, 8000)\n    iex> new_config.wait_timeout\n    8000","ref":"Testcontainers.RedisContainer.html#with_wait_timeout/2-examples"},{"type":"module","title":"Testcontainers.SeleniumContainer","doc":"Work in progress. Not stable for use yet. Not yet documented for this very reason.\nCan use https://github.com/stuart/elixir-webdriver for client in tests","ref":"Testcontainers.SeleniumContainer.html"},{"type":"function","title":"Testcontainers.SeleniumContainer.default_image/0","doc":"","ref":"Testcontainers.SeleniumContainer.html#default_image/0"},{"type":"function","title":"Testcontainers.SeleniumContainer.new/0","doc":"","ref":"Testcontainers.SeleniumContainer.html#new/0"},{"type":"function","title":"Testcontainers.SeleniumContainer.with_image/2","doc":"","ref":"Testcontainers.SeleniumContainer.html#with_image/2"},{"type":"function","title":"Testcontainers.SeleniumContainer.with_port1/2","doc":"","ref":"Testcontainers.SeleniumContainer.html#with_port1/2"},{"type":"function","title":"Testcontainers.SeleniumContainer.with_port2/2","doc":"","ref":"Testcontainers.SeleniumContainer.html#with_port2/2"},{"type":"function","title":"Testcontainers.SeleniumContainer.with_wait_timeout/2","doc":"","ref":"Testcontainers.SeleniumContainer.html#with_wait_timeout/2"},{"type":"protocol","title":"Testcontainers.WaitStrategy","doc":"Defines the protocol/interface for the wait strategies in `Testcontainers`","ref":"Testcontainers.WaitStrategy.html"},{"type":"function","title":"Testcontainers.WaitStrategy.wait_until_container_is_ready/3","doc":"","ref":"Testcontainers.WaitStrategy.html#wait_until_container_is_ready/3"},{"type":"type","title":"Testcontainers.WaitStrategy.t/0","doc":"All the types that implement this protocol.","ref":"Testcontainers.WaitStrategy.html#t:t/0"}],"content_type":"text/markdown"}